==> cerebral-module-signal-store-0.0.2.tgz: package/README.md <==
# cerebral-module-signal-store
Cerebral module to store signals

[![NPM version][npm-image]][npm-url]
[![Build status][travis-image]][travis-url]
[![Test coverage][coveralls-image]][coveralls-url]
[![bitHound Score][bithound-image]][bithound-url]
[![Commitizen friendly][commitizen-image]][commitizen-url]
[![Semantic Release][semantic-release-image]][semantic-release-url]
[![js-standard-style][standard-image]][standard-url]
[![Discord][discord-image]][discord-url]

[npm-image]: https://img.shields.io/npm/v/cerebral-module-signal-store.svg?style=flat
[npm-url]: https://npmjs.org/package/cerebral-module-signal-store
[travis-image]: https://img.shields.io/travis/cerebral/cerebral-module-signal-store.svg?style=flat
[travis-url]: https://travis-ci.org/cerebral/cerebral-module-signal-store
[coveralls-image]: https://img.shields.io/coveralls/cerebral/cerebral-module-signal-store.svg?style=flat
[coveralls-url]: https://coveralls.io/r/cerebral/cerebral-module-signal-store?branch=master
[bithound-image]: https://www.bithound.io/github/cerebral/cerebral-module-signal-store/badges/score.svg
[bithound-url]: https://www.bithound.io/github/cerebral/cerebral-module-signal-store
[commitizen-image]: https://img.shields.io/badge/commitizen-friendly-brightgreen.svg
[commitizen-url]: http://commitizen.github.io/cz-cli/
[semantic-release-image]: https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg?style=flat
[semantic-release-url]: https://github.com/semantic-release/semantic-release
[standard-image]: https://img.shields.io/badge/code%20style-standard-brightgreen.svg
[standard-url]: http://standardjs.com/
[discord-image]: https://img.shields.io/badge/discord-join%20chat-blue.svg
[discord-url]: https://discord.gg/0kIweV4bd2bwwsvH

==> cerebral-module-signal-store-0.1.8.tgz: package/README.md <==
# cerebral-module-signal-store
Time travel enabler for Cerebral application 

[![NPM version][npm-image]][npm-url]
[![Build status][travis-image]][travis-url]
[![Test coverage][coveralls-image]][coveralls-url]
[![bitHound Score][bithound-image]][bithound-url]
[![Commitizen friendly][commitizen-image]][commitizen-url]
[![Semantic Release][semantic-release-image]][semantic-release-url]
[![js-standard-style][standard-image]][standard-url]
[![Discord][discord-image]][discord-url]

Currently it used as submodule of [cerebral-module-devtools](https://github.com/cerebral/cerebral-module-devtools) and there is no need to include it as top level module.
Still feel free to inspect it and create own cool stuff based on it.

[npm-image]: https://img.shields.io/npm/v/cerebral-module-signal-store.svg?style=flat
[npm-url]: https://npmjs.org/package/cerebral-module-signal-store
[travis-image]: https://img.shields.io/travis/cerebral/cerebral-module-signal-store.svg?style=flat
[travis-url]: https://travis-ci.org/cerebral/cerebral-module-signal-store
[coveralls-image]: https://img.shields.io/coveralls/cerebral/cerebral-module-signal-store.svg?style=flat
[coveralls-url]: https://coveralls.io/r/cerebral/cerebral-module-signal-store?branch=master
[bithound-image]: https://www.bithound.io/github/cerebral/cerebral-module-signal-store/badges/score.svg
[bithound-url]: https://www.bithound.io/github/cerebral/cerebral-module-signal-store
[commitizen-image]: https://img.shields.io/badge/commitizen-friendly-brightgreen.svg
[commitizen-url]: http://commitizen.github.io/cz-cli/
[semantic-release-image]: https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg?style=flat-square
[semantic-release-url]: https://github.com/semantic-release/semantic-release
[standard-image]: https://img.shields.io/badge/code%20style-standard-brightgreen.svg
[standard-url]: http://standardjs.com/
[discord-image]: https://img.shields.io/badge/discord-join%20chat-blue.svg
[discord-url]: https://discord.gg/0kIweV4bd2bwwsvH
